* This program is for descriptive analysis of mental health variables in the SYPE panel

* clear memory
clear
matrix drop _all
clear matrix
clear mata
set maxvar 8000
set matsize 10000
set more off


/*  CONTENTS:

	1. Set up SYPE panel
		1.1 Merge 2009 and 2009 special variables
		1.2 Merge 2009 and 2014 waves
		1.3 Merge in 'Date and time.dta' to get 2009 interview date
	2. Code SYPE standardized variables
		2.1 Merge in 'Date and time.dta' to get 2009 interview date
		2.2 Code standardized variables
	3. Code additional covariates
	4. Code MH variables - simple indices
		4.1 2009 wave
		4.2 2014 wave
		4.3 Difference between waves
	5. Descriptives for simple MH indices
		5.1 Sample characteristics
		5.2 MH measures across waves
		5.3 MH measures by background characteristics
		5.4 MH measures by gender & age/marital change/LF transitions
														*/
	

*** DEFINE MACROS *****************************

local MH "mh22 mh23 mh24 mh25 mh26 mh27 mh28 mh29 mh30 mh31 mh32 mh33 mh34 mh35 mh36 mh37 mh38 mh39 mh40 mh41 poormh"	
	
***********************************************
	
*--------------------------------------
/* 1. Set up SYPE panel	for 2009 and 2014 waves */
*---------------------------------------


* 1.1 Merge 2009 and 2009 special variables
*---------------------------------------

use "SYPE_V_1.6.2 with new weights final 2009.dta", clear
drop if EligW==.

merge 1:1 hh_id pn using "SYPE 2009 special variables.dta"
drop _merge

quietly: for var gov - hhsize: rename X X_09
save "SYPE 2009_youth only.dta", replace
clear

* 1.2 Merge 2009 and 2014 waves
*---------------------------------------

use "SYPE 2014 V4.5.dta", clear
sort hh_id pn

merge 1:1 hh_id pn using "SYPE 2009_youth only.dta"
drop _merge

save "SYPE panel.dta", replace
	
	
*--------------------------------------
/* 2. Standard SYPE-coded variables	*/
* create same variables for 2009 and 2014 waves
*---------------------------------------

* Start with SYPE panel
use "SYPE panel.dta", clear

* 2.1 Merge in 2009 interview dates
* NOTE: The "Date and time 2009.dta" dataset contains the following variables necessary to construct the interview date for the 2009 wave:
*	LAST_MEET_YEAR, LAST_MEET_MONTH, LAST_MEET_DAY
*	This dataset must be obtained with special permission from the Population Council (see README file)
*---------------------------------------

merge m:1 hh_id using "Date and time 2009.dta"
drop _merge

* number of observations
count

* restrict to panel set
keep if expan_Elig!=. 
count

* 2.2 Code standardized variables
*---------------------------------------

* drop Sinai
drop if GOV==34 | GOV==35

* sex 
tab sex
tab sex, nol

gen male = sex==1
label var male "male"

label define sex	0 "f" 1 "m"
label val male sex

* age
rename age age14
rename q_5_09 age09

* check on people with strange ages
gen age_diff = age14-age09
tab age_diff
count if age_diff <1 
count if inrange(age_diff, 7, 23)

drop if age_diff <-4		// drop those who seem to have implausible ages (n=32)

* age groups 
label define age	1 "13" ///
					2 "18" ///
					3 "25" ///
					4 "30"
label val Age_Eligible2 age
tab Age_Eligible2, gen(agecat)


* geopolitical region - regions map 1:1 across waves
tab Metro_region
rename Metro_region Metro_region14
tab Metro_region14, gen(region)

* urban/rural - residency maps 1:1 across waves
tab residency
rename residency residency14
rename residency_09 residency09
tab residency14 residency09, nol
tab residency14, gen(resid)

* HH moved
gen movedhh = MOVE_YY!=.
replace movedhh = 0 if inrange(MOVE_YY, 2003, 2008)	/* some HH have year prior to first wave */
label var movedhh "HH moved since 2009"

* Education
* start with 2009 status 
gen		educstatus09 = 1 if q_240_09==1					// never went
replace educstatus09 = 2 if q_240_09==2					// currently in school
replace educstatus09 = 3 if inlist(q_240_09, 3, 4)		//out of school: finished, dropped out, or homeschooled

label def educ_stat	1 "never went" ///
					2 "currently in school" ///
					3 "out of school" 
label val educstatus09 educ_stat
label var educstatus09 "schooling status"

* ID level completed in 2009
gen 	levelcomp09 = 0 if educstatus09==1										// never went
replace	levelcomp09 = 0 if inlist(q_246_09, 1)							 		// still in primary
replace levelcomp09 = 1 if inlist(q_246_09, 2, 3)	| inlist(q_241_09, 1, 2) 	// completed primary
replace levelcomp09 = 2 if inlist(q_246_09, 4, 5) 	| inlist(q_241_09, 3, 4) 	// completed prepatory
replace levelcomp09 = 3 if inlist(q_246_09, 6, 7)	| inlist(q_241_09, 5, 6, 8) // secondary
replace levelcomp09 = 4 if inlist(q_246_09, 8)		| inlist(q_241_09, 7)    	// voc secondary
replace levelcomp09 = 5 if inlist(q_246_09, 10, 11) | inlist(q_241_09, 9, 10, 11) // beyond secondary

label def educ_level	0 "none" ///
						1 "primary" ///
						2 "preparatory" ///
						3 "secondary"  ///
						4 "voc secondary" ///
						5 "beyond secondary"
label val levelcomp09 educ_level
label var levelcomp09 "highest level completed 2009"

* 2014 status
gen		educstatus14 = 1 if Q1101==1				// never went
replace educstatus14 = 2 if Q1101==2				// currently in school
replace educstatus14 = 3 if inlist(Q1101, 3, 4) 	// out of school: finished, dropped out, or homeschooled
label val educstatus14 educ_stat
label var educstatus14 "schooling status"
	
* 2014 level attended
gen		levelatt14 = 0 if educstatus14==1			// never went
replace	levelatt14 = 1 if inlist(Q1105, 1, 2)		// primary
replace levelatt14 = 2 if inlist(Q1105, 3, 4) 		// prepatory
replace levelatt14 = 3 if inlist(Q1105, 5, 6, 9)	// secondary
replace levelatt14 = 4 if inlist(Q1105, 7, 8)  		// voc secondary
replace levelatt14 = 5 if inrange(Q1105, 9, 13) 	// beyond secondary
label val levelatt14 educ_level
label var levelatt14 "educ level attended in 2014"	
	
tab educstatus09 educstatus14	

* reason for dropout in 2014
gen reason = ""
foreach i of newlist A B C D E F G H I J K L M N O P Q R S T U V W {
	replace reason = "`i'" if Q1102_`i'==1
}

* educ status recodes to clean up transitions

*3. never went in 2009 --> out of school
replace levelcomp09 = 0 		 if educstatus09==1 & educstatus14==3 & inlist(levelatt14, 1) & Q1106_A<5  			// set 2009 level none if not finished primary
replace levelcomp09 = levelatt14 if educstatus09==1 & educstatus14==3 & inlist(levelatt14, 1) & Q1106_A>=5 			// set 2009 level to primary if finished primary
replace levelcomp09 = levelatt14 if educstatus09==1 & educstatus14==3 & inlist(levelatt14, 2, 3, 4) & Q1106_A>=3 	// set 2009 level to 2014 level for those completing the requisite # yrs for prep/sec school
replace levelcomp09 = levelatt14-1 	if educstatus09==1 & educstatus14==3 & inlist(levelatt14, 2, 3, 4) & Q1106_A<3 	// set 2009 level to one level lower than 2014 level for those not completing the requisite # yrs for prep/sec school

replace educstatus09 = 3 		 if educstatus09==1 & educstatus14==3 				// set 2009 status to out of school
  
*4. currently in school in 2009 --> never went
replace levelatt14 = 0 	 if educstatus09==2 & educstatus14==1 & levelcomp09==0 	// 2014 level set to none
replace educstatus14 = 3 if educstatus09==2 & educstatus14==1 & levelcomp09==0 	// was in primary, but never finished; recode to drop out in 2014

replace levelatt14 = levelcomp09 if educstatus09==2 & educstatus14==1 & inrange(levelcomp09, 1, 3)	// set 2014 level to 2009 level
replace educstatus14 = 3		 if educstatus09==2 & educstatus14==1 & inrange(levelcomp09, 1, 3)	// set 2014 status to finished

*6. currently in school --> out of school (recode exceptional cases where level in 2014 is lower than 2009 level; no change in status)
replace levelatt14 = levelcomp09 if educstatus09==2 & educstatus14==3 & levelcomp09>levelatt14	// set 2014 level to 2009 level

*7. out of school --> never went
replace levelatt14 = levelcomp09 if educstatus09==3 & educstatus14==1 // set 2014 level to 2009 level
replace educstatus14 = 3 		 if educstatus09==3 & educstatus14==1 // set 2014 status to out of school (all answered yes to q244 for enough schooling)

*8. out of school --> currently in school (most are okay; 4 exceptional cases)
replace levelatt14 = levelcomp09 if educstatus09==3 & educstatus14==2 & (indid=="0513205" | ///
																		 indid=="0035703" | ///
																		 indid=="0535306" | ///
																		 indid=="0085701" )	// set 2014 level to 2009 level
replace educstatus14 = 3		 if educstatus09==3 & educstatus14==2 & (indid=="0513205" | ///
																		 indid=="0035703" | ///
																		 indid=="0535306" | ///
																		 indid=="0085701")	// set 2014 status to finished

*9. out of school --> out of school (many have returned to school and finished at a higher level; only recode cases if 2014 level is lower than 2009 level)
replace levelatt14 = levelcomp09 if educstatus09==3 & educstatus14==3 & levelatt14<levelcomp09	// set 2014 level to 2009 level 

* make flag for people who appeared to have returned to school between waves
gen 	educreturn = 1 if educstatus09==3 & educstatus14==2 
replace educreturn = 1 if educstatus09==3 & educstatus14==3 & levelcomp09<levelatt14

* code major transitions
tab educstatus09 educstatus14

gen 	eductrans = 1 if educstatus09==1 & educstatus14==1 // never went ever
replace eductrans = 2 if educstatus09==1 & educstatus14==2 // started school, currently attending

replace eductrans = 3 if educstatus09==2 & educstatus14==2 // still in school
replace eductrans = 4 if educstatus09==2 & educstatus14==3 // was in school, now out

replace eductrans = 5 if educstatus09==3 & educstatus14==2 & educreturn==1	// out of school, but went back and currently attending
replace eductrans = 6 if educstatus09==3 & educstatus14==3 				 	// out of school, stayed out
replace eductrans = 7 if educstatus09==3 & educstatus14==3 & educreturn==1 	// out of school, went back and finished again

label define educ_transitions	1 "never went ever" ///
								2 "started school, currently attending" ///
								3 "was in school and still is" ///
								4 "was in school, now out" ///
								5 "out of school, went back, currently attending" ///
								6 "out of school, stayed out"	///
								7 "out of school, went back & finished"
label val eductrans educ_transitions

* wealth quintiles (use baseline measure)		
tab wiq_09, gen(wealth)
tab wiq_09, nol
rename wiq_09 wiq09

rename wiq wiq14

* employment status
* NOTE: The 2009 variable is not in the public data file. Special permission is required to obtain this variable.
rename empsts empsts14
rename empsts_09 empsts09
tab empsts09 empsts14
tab empsts09, gen(emp09_)
tab empsts14, gen(emp14_)

* student
drop student*

gen student09 = educstatus09==2
replace student09 = . if educstatus09==.

gen student14 = educstatus09==14
replace student14 = . if educstatus14==.

tab student09 student14

* schooling status for those out of labor force 
drop OLFinschl 

gen OLFinschl09=.
replace OLFinschl09=1 if empsts09==3 & student09==1
replace OLFinschl09=0 if empsts09==3 & student09==0
label var OLFinschl09 "schooling status for those OLF"

gen OLFinschl14=.
replace OLFinschl14=1 if empsts14==3 & student14==1
replace OLFinschl14=0 if empsts14==3 & student14==0
label var OLFinschl14 "schooling status for those OLF"


*------------------------------------
/* 3. Create additional covariates */
*------------------------------------

* unique kism identifier
gen kismid = GOV*100 + KISM
label var kismid "unique kism ID"

* date of interview
gen x = (LAST_MEET_YEAR*10000 + LAST_MEET_MONTH*100 + LAST_MEET_DAY)
tostring x, replace
gen double intdate09 = date(x, "YMD")
format intdate09 %tdnn/dd/YY
drop x
label var intdate09 "2009 interview date"


* date of interview - 2014 (854 missings)
gen x = (VISIT_YY*10000 + VISIT_MM*100 + VISIT_DD)
tostring x, replace
gen double intdate14 = date(x, "YMD")
format intdate14 %tdnn/dd/YY
drop x VISIT*
label var intdate14 "2014 interview date"

* religion (use baseline 2009 value)
* NOTE: This variable is not in the public data file. Special permission is required to obtain this variable.
tab q_105_09
tab q_105_09, nol

gen muslim = q_105_09==1
label var muslim "muslim"
*/

* HH size
* NOTE: The 2009 variable is not in the public data file. Special permission is required to obtain this variable.
gen hhsize14 = TOT_FMLY
recode hhsize14 80=.	/* this appears to be an egregious outlier */
rename hhsize_09 hhsize09
tablist hhsize09 hhsize14

* age at first marriage
tab Q10
gen agefm14 = Q10
gen agefm09 = q20_09
tablist agefm09 agefm14, sort(v)  

* marital status (ever married)
* NOTE: The 2009 variable is not in the public data file. Special permission is required to obtain this variable.

rename evrmar evrmar14
tab evrmar14, nol

tab evrmarried_09, m 	/* 3155 missings bc not asked for <15 in 2009 */
rename evrmarried_09 evrmar09
replace evrmar09 = 1 if agefm14 <= age09	/* if age of 1st mar is before 2009 age */
replace evrmar09 = 0 if evrmar14==0			/* if not married in 2014, then not married in 2009 */
replace evrmar09 = 0 if agefm14 > age09		/* if age of 1st mar is after 2009 age */

* clean up age at first marriage
replace agefm09 = agefm14 if evrmar09==1 & agefm09==.	/* if married in 09, take age from 2014 wave for missings */

* make composite age at first marriage variable
* use 09 value for discrepancies
gen agefm = agefm09
replace agefm = agefm14 if agefm==.
label var agefm "age at first marriage"

* ID those who got married between waves
gen gotmarried = evrmar14==1 & evrmar09==0
replace gotmarried = . if evrmar14==. | evrmar09==.
label var gotmarried "got married between waves"

* number of children
gen numboy14 = Q4107_A
gen numgirl14 = Q4107_B
gen numkid14 = Q4107_C
for var num*14: recode X 99=.
tablist numboy14 numgirl14 numkid14

* employment transitions
* a) anything --> employed
gen gotemp = inlist(empsts09, 2, 3) & empsts14==1
label var gotemp "got employed between waves"

* b) employed --> anything
gen gotunemp = empsts09==1 & inlist(empsts14, 2, 3)
label var gotunemp "got unemployed between waves"

* c) OLF --> unemployed
gen olftounemp = empsts09==3 & empsts14==2
label var olftounemp "was OLF, transition to unemployed"

* composite of (a) & (b)
label define emptransitions	0 "none" ///
							1 "emp" ///
							2 "unemp"

gen emptrans = 0 if gotemp==0 & gotunemp==0
replace emptrans = 1 if gotemp==1
replace emptrans = 2 if gotunemp==1
label val emptrans emptransitions
label var emptrans "emplyment transitions"

for var gotemp gotunemp olftounemp emptrans: replace X = . if empsts09==. | empsts14==.

* on time or delayed in school, for those who were ever in school at one time
gen 	educdelay14 = 0
replace educdelay14 = . if eductrans==. 

replace educdelay14 = 1 if age14<=13 & (levelatt14<1 | ///			// not completing primary by age 13
									(levelatt14==1 & Q1106_A<5)) & (educstatus09==2 | educstatus14==2)
replace educdelay14 = 1 if age14<=16 & (levelatt14<2 | ///			// not completing preparatory by age 16
									(levelatt14==2 & Q1106_A<3)) & (educstatus09==2 | educstatus14==2)
replace educdelay14 = 1 if age14<=19 & (levelatt14<3 | ///			// not completing secondary by age 19
									(inrange(levelatt14, 3, 4) & Q1106_A<3))  & (educstatus09==2 | educstatus14==2)

gen 	educdelay09 = 0
replace educdelay09 = . if eductrans==.
replace educdelay09 = 1 if age14<=13-(year(intdate14)-year(intdate09)) & levelcomp09<1 & (educstatus09==2 | educstatus14==2)	// not completing primary by age 13
replace educdelay09 = 1 if age14<=16-(year(intdate14)-year(intdate09)) & levelcomp09<2 & (educstatus09==2 | educstatus14==2)	// not completing preparatory by age 16
replace educdelay09 = 1 if age14<=19-(year(intdate14)-year(intdate09)) & levelcomp09<3 & (educstatus09==2 | educstatus14==2)	// not completing secondary by age 19
replace educdelay09 = 1 if age14<=13-(2014-2009) & levelcomp09<1 & (educstatus09==2 | educstatus14==2)		// not completing primary by age 13
replace educdelay09 = 1 if age14<=16-(2014-2009) & levelcomp09<2 & (educstatus09==2 | educstatus14==2)		// not completing preparatory by age 16
replace educdelay09 = 1 if age14<=19-(2014-2009) & levelcomp09<3 & (educstatus09==2 | educstatus14==2)		// not completing secondary by age 19

tab educdelay09 educdelay14


*-----------------------------
/* 4. MH variables 	*/
*-----------------------------

/* 4.1 2009 wave 
** NOTE: MH Qs only asked for age 15+ in 2009*/

describe q_622-q_641
codebook q_622-q_641

tab age09 q_622, m

* rename all variables to be consistent
foreach i of numlist 22(1)41 {
	rename q_6`i' mh`i'_09
}
d mh*09

* sum all items
egen mhsum_09 = rowtotal(mh22_09-mh41_09), missing
label var mhsum_09 "MH summary index"

* dummy variable
gen poormh_09 = mhsum_09>=8
replace poormh_09 = . if mhsum_09==.
label var poormh_09 "MH index>=8"


/* 4.2 2014 wave */

describe Q4227-Q4246
codebook Q4227-Q4246

* recode and rename all variables to be consistent
rename Q4227 mh22_14
rename Q4228 mh23_14
rename Q4229 mh24_14
rename Q4230 mh25_14
rename Q4231 mh26_14
rename Q4232 mh27_14
rename Q4233 mh28_14
rename Q4234 mh29_14
rename Q4235 mh30_14
rename Q4236 mh31_14
rename Q4237 mh32_14
rename Q4238 mh33_14
rename Q4239 mh34_14
rename Q4240 mh35_14
rename Q4241 mh36_14
rename Q4242 mh37_14
rename Q4243 mh38_14
rename Q4244 mh39_14
rename Q4245 mh40_14
rename Q4246 mh41_14

d mh*14

for var mh22_14-mh41_14: recode X 2=0
codebook mh22_14-mh41_14

* sum all items
egen mhsum_14 = rowtotal(mh22_14-mh41_14), missing
label var mhsum_14 "MH summary index"

* dummy variable
gen poormh_14 = mhsum_14>=8
replace poormh_14 = . if mhsum_14==.
label var poormh_14 "MH index>=8"


/* 4.3 difference between waves */

* take first difference
foreach i of numlist 22(1)41 {
	gen mh`i'_fd = mh`i'_14-mh`i'_09
	label var mh`i'_fd "`: var label mh`i'_14' fd"
	gen mh`i'_i = mh`i'_fd==1
	replace mh`i'_i = . if mh`i'_fd==.
	label var mh`i'_i "`: var label mh`i'_14' increase"
	gen mh`i'_d = mh`i'_fd==-1
	replace mh`i'_d = . if mh`i'_fd==.
	label var mh`i'_d "`: var label mh`i'_14' decrease"
}

gen mhsum_fd = mhsum_14 - mhsum_09
label var mhsum_fd "MH index fd"

gen poormh_fd = poormh_14 - poormh_09
label var poormh_fd "Poor MH fd"

gen poormh_i = poormh_fd==1
replace poormh_i = . if poormh_fd==.
label var poormh_i "Poor MH increase"

gen poormh_d = poormh_fd==-1
replace poormh_d = . if poormh_fd==.
label var poormh_d "Poor MH decrease"


* ID sampe that has MH variables for both waves
gen mhsample = mhsum_09!=. & mhsum_14!=.
label var mhsample "MH sample"
tab mhsample									/* N=7455 */

* drop people younger than 18 in 2014
drop if age14<18

* keep only MH panel sample
keep if mhsample==1


/*--------------------------
* 5. Look at raw descriptives
*-------------------------- */

/* 5.1 Sample charactericts */
set more off

* full panel sample
tabstat age14 male agecat* evrmar09 evrmar14 agefm ///
		hhsize09 hhsize14 wealth1-wealth5 emp09_1-emp09_3 emp14_1-emp14_3 ///
		gotemp gotunemp olftounemp ///
		student09 student14 muslim numkid14 ///
		region1-region6 resid1-resid3 [aw=expan_Elig], long c(s)

* sample that has MH variables
tabstat age14 male agecat* evrmar09 evrmar14 agefm ///
		hhsize09 hhsize14 wealth1-wealth5 emp09_1-emp09_3 emp14_1-emp14_3 ///
		gotemp gotunemp olftounemp ///
		student09 student14 muslim numkid14 ///
		region1-region6 resid1-resid3 if mhsample==1 [aw=expan_Elig], long c(s)
		
* age by sex
kdensity age14 if male==0 [aw=expan_Elig], ///
	addplot(kdensity age14 if male==1) ///
	legend(ring(0) pos(2) label(1 "Female") label(2 "Male")) ///
	xtitle("Age of participant") name("fullsample", replace) ///
	title("full panel sample", size(small))
		
kdensity age14 if male==0 & mhsample==1 [aw=expan_Elig], ///
	addplot(kdensity age14 if male==1 & mhsample==1) ///
	legend(ring(0) pos(2) label(1 "Female") label(2 "Male")) ///
	xtitle("Age of participant") name("mhsample", replace)  ///
	title("MH sample", size(small))

grc1leg fullsample mhsample, cols(1)
graph save "age_distribution.gph", replace


/* 5.2 MH measures across waves */
tabstat mh22_09-mh41_09 mhsum_09 poormh_09 [aw=expan_Elig], long c(s) stat(n mean sd)
tabstat mh22_14-mh41_14 mhsum_14 poormh_14 [aw=expan_Elig], long c(s) stat(n mean sd)
tabstat mh22_14-mh41_14 mhsum_14 poormh_14 if mhsample==1 [aw=expan_Elig], long c(s) stat(n mean sd)
tabstat mh22_fd-mh41_fd mhsum_fd poormh_fd [aw=expan_Elig], long c(s) stat(n mean sd)

graph bar (mean) mh22_09-mh41_09 poormh_09 [aw=expan_Elig], percentage ///
	legend(size(small) cols(4) span) name("MH2009", replace)          ///
	title("2009", size(small)) ytitle("", size(small))

graph bar (mean) mh22_14-mh41_14 poormh_14 [aw=expan_Elig], percentage ///
	legend(size(small) cols(4) span) name("MH2014", replace)          ///
	title("2014", size(small)) ytitle("", size(small))

graph bar (mean) mh2*_fd mh3*_fd mh4*_fd poormh_fd [aw=expan_Elig], percentage ///
	legend(size(small) cols(4) span) name("MHfd", replace)          ///
	title("Difference", size(small)) ytitle("", size(small))
	
grc1leg MH2009 MH2014 MHfd, cols(1) imargin(l=1 r=1) title(MH measures)
graph save "mhcompare.gph", replace	

* compare by gender within wave
cdfplot mhsum_09 [aw=expan_Elig], by(male)
cdfplot mhsum_14 [aw=expan_Elig], by(male)

	
/* 5.3 MH measures by background characteristics */
local MH "mh22 mh23 mh24 mh25 mh26 mh27 mh28 mh29 mh30 mh31 mh32 mh33 mh34 mh35 mh36 mh37 mh38 mh39 mh40 mh41 poormh"	
set more off
* by gender
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexgraphs `sexgraphs' x`i'
}
grc1leg `sexgraphs', imargin(l=1 r=1) title(By gender)
graph save "mhbygender.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(male) ///
	legend(order(1 "2009" 2 "2014"))
graph save "mhsumbygender.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexgraphsfd `sexgraphsfd' x`i'
}
grc1leg `sexgraphsfd', imargin(l=1 r=1) title(By gender - difference)
graph save "mhbygenderfd.gph", replace

* by age
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(Age_Eligible2) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local agegraphs `agegraphs' x`i'
}
grc1leg `agegraphs', imargin(l=1 r=1) title(By age)
graph save "mhbyage.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(Age_Eligible2) ///
	legend(order(1 "2009" 2 "2014"))	
graph save "mhsumbyage.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(Age_Eligible2) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local agegraphsfd `agegraphsfd' x`i'
}
grc1leg `agegraphsfd', imargin(l=1 r=1) title(By age - difference)
graph save "mhbyagefd.gph", replace

* wealth
local MH "mh22 mh23 mh24 mh25 mh26 mh27 mh28 mh29 mh30 mh31 mh32 mh33 mh34 mh35 mh36 mh37 mh38 mh39 mh40 mh41 poormh"	

foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(wiq09) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local wealthgraphs `wealthgraphs' x`i'
}
grc1leg `wealthgraphs', imargin(l=1 r=1) title(By wealth)
graph save "mhbywealth.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(wiq09) ///
	legend(order(1 "2009" 2 "2014"))	
graph save "mhsumbywealth.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(wiq09) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local wealthgraphsfd `wealthgraphsfd' x`i'
}
grc1leg `wealthgraphsfd', imargin(l=1 r=1) title(By wealth - difference)
graph save "mhbywealthfd.gph", replace

* residence
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(residency09) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local residgraphs `residgraphs' x`i'
}
grc1leg `residgraphs', imargin(l=1 r=1) title(By residency)
graph save "mhbyresid.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(residency09) ///
	legend(order(1 "2009" 2 "2014"))	
graph save "mhsumbyresid.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(residency09) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local residgraphsfd `residgraphsfd' x`i'
}
grc1leg `residgraphsfd', imargin(l=1 r=1) title(By residency - difference)
graph save "mhbyresidfd.gph", replace

* got married
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(gotmarried) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local maritalgraphs `maritalgraphs' x`i'
}
grc1leg `maritalgraphs', imargin(l=1 r=1) title(By got married)
graph save "mhbymarital.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(gotmarried) ///
	legend(order(1 "2009" 2 "2014"))	
graph save "mhsumbymarital.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(gotmarried) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local maritalgraphsfd `maritalgraphsfd' x`i'
}
grc1leg `maritalgraphsfd', imargin(l=1 r=1) title(By got married - difference)
graph save "mhbymaritalfd.gph", replace

* employment transitions
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(emptrans) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local emptransgraphs `emptransgraphs' x`i'
}
grc1leg `emptransgraphs', imargin(l=1 r=1) title(By employment transitions)
graph save "mhbyemployt.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(emptrans) ///
	legend(order(1 "2009" 2 "2014"))	
graph save "mhsumbyemployt.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(emptrans) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local emptransgraphsfd `emptransgraphsfd' x`i'
}
grc1leg `emptransgraphsfd', imargin(l=1 r=1) title(By employment transitions - difference)
graph save "mhbyempoytfd.gph", replace

* entering labor market, but being unemployed
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(olftounemp) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local olfgraphs `olfgraphs' x`i'
}
grc1leg `olfgraphs', imargin(l=1 r=1) title(By OLF to unemployment)
graph save "mhbyolf.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(olftounemp) ///
	legend(order(1 "2009" 2 "2014"))	
graph save "mhsumbyolf.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(olftounemp) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local olfgraphsfd `olfgraphsfd' x`i'
}
grc1leg `olfgraphsfd', imargin(l=1 r=1) title(By OLF to unemployment - difference)
graph save "mhbyolffd.gph", replace


/* 5.4 MH by gender & age/marital change/LF transitions */

* by gender & age
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(Age_Eligible2) over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexagegraphs `sexagegraphs' x`i'
}
grc1leg `sexagegraphs', imargin(l=1 r=1) title(By gender-age)
graph save "mhbygenderage.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(Age_Eligible2) over(male) ///
	legend(order(1 "2009" 2 "2014"))
graph save "mhsumbygenderage.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(Age_Eligible2) over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexagegraphsfd `sexagegraphsfd' x`i'
}
grc1leg `sexagegraphsfd', imargin(l=1 r=1) title(By gender/age - difference)
graph save "mhbygenderagefd.gph", replace

local MH "mh22 mh23 mh24 mh25 mh26 mh27 mh28 mh29 mh30 mh31 mh32 mh33 mh34 mh35 mh36 mh37 mh38 mh39 mh40 mh41 poormh"	

* by gender & got married
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(gotmarried) over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexmargraphs `sexmargraphs' x`i'
}
grc1leg `sexmargraphs', imargin(l=1 r=1) title(By gender-got married)
graph save "mhbygendermar.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(gotmarried) over(male) ///
	legend(order(1 "2009" 2 "2014"))
graph save "mhsumbygendermar.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(gotmarried) over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexmargraphsfd `sexmargraphsfd' x`i'
}
grc1leg `sexmargraphsfd', imargin(l=1 r=1) title(By gender/got married - difference)
graph save "mhbygendermarfd.gph", replace


* by gender & LF transitions
foreach i of local MH {
	graph bar (mean) `i'_09 `i'_14 [aw=expan_Elig], over(emptrans) over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "2009" 2 "2014"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexempgraphs `sexempgraphs' x`i'
}
grc1leg `sexempgraphs', imargin(l=1 r=1) title(By gender-LF transitions)
graph save "mhbygenderemp.gph", replace

graph box mhsum_09 mhsum_14 if mhsample==1 [aw=expan_Elig], over(emptrans) over(male) ///
	legend(order(1 "2009" 2 "2014"))
graph save "mhsumbygenderemp.gph", replace

foreach i of local MH {
	graph bar (mean) `i'_i `i'_d [aw=expan_Elig], over(emptrans) over(male) percentage ///
	legend(size(small)) name(x`i', replace)          ///
	legend(order(1 "increase" 2 "decrease"))	///
	title("`: var label `i'_14'", size(small)) ytitle("", size(small))
local sexempgraphsfd `sexempgraphsfd' x`i'
}
grc1leg `sexempgraphsfd', imargin(l=1 r=1) title(By gender/LF transitions - difference)
graph save "mhbygenderempfd.gph", replace

/* SAVE FILE */
save "MH_descriptive.dta", replace

